==> tasks-v1.8.8.zip: tasks/messages/sr/base.php <==
<?php

return [
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Dodeljeni korisnici</strong> smeju raditi na ovom zadatku.',
    '<strong>Confirm</strong> task deletion' => '<strong>Potvrdi</strong> brisanje zadatka',
    '<strong>Create</strong> task list' => '<strong>Stvori</strong> listu zadataka',
    '<strong>Edit</strong> task' => '<strong>Uredi</strong> zadatak',
    '<strong>Edit</strong> task list' => '<strong>Uredi</strong> listu zadataka',
    '<strong>Task</strong> Overview' => '<strong>Zadatak</strong> Pregled',
    '<strong>Your</strong> tasks' => '<strong>Vaši</strong> zadaci',
    'Accept Task' => 'Prihvati zadatak',
    'Add Deadline to space calendar' => 'Dodajte rok u kalendar prostora',
    'Add checkpoint...' => 'Dodaj završnu tačku...',
    'Add reminder' => 'Dodaj podsetnik',
    'Add responsible users' => 'Dodajte odgovorne korisnike',
    'Add schedule to the space calendar' => 'Dodajte raspored u kalendar prostora',
    'Add task' => 'Dodaj zadatak',
    'Add to space calendar' => 'Dodaj u kalendar prostora',
    'All Day' => 'Celi dan',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Omogućuje korisniku kreiranje novih zadataka, korisnik će moći uređivati i brisati samo svoje zadatke',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Omogućuje korisniku stvaranje, brisanje i uređivanje zadataka i popisa te sortiranje zadataka i popisa',
    'Allows the user to process unassigned tasks' => 'Omogućuje korisniku obradu neraspoređenih zadataka',
    'Already requested' => 'Već zatraženo',
    'Anyone can work on this task!' => 'Svako može raditi na ovom zadatku!',
    'Assign users' => 'Dodeli korisnike',
    'Assignment' => 'Zadatak',
    'Assignments:' => 'Dodijeljeno:',
    'Begin Task' => 'Započnite zadatak',
    'Checklist Items' => 'Stavke ček liste',
    'Checklist:' => 'Lista za čekiranje:',
    'Close' => 'Zatvori',
    'Color' => 'Boja',
    'Completed' => 'Dovršeno',
    'Continue Review' => 'Nastavite s pregledom',
    'Create tasks' => 'Kreiraj zadataka',
    'Created by me' => 'Kreirao sam',
    'Date' => 'Datum',
    'Deadline: ' => 'Rok:',
    'Delete' => 'Obriši',
    'Delete list' => 'Izbriši listu',
    'Description' => 'Opis',
    'Do you really want to delete this task?' => 'Želite li stvarno izbrisati taj zadatak?',
    'Don\'t add to calendar' => 'Ne dodavaj u kalendar',
    'Drag entry' => 'Povuci unos',
    'Edit' => 'Uredi',
    'Edit item (empty field will be removed)...' => 'Uredi stavku (prazno polje će biti uklonjeno) ...',
    'Edit list' => 'Uredi listu',
    'End' => 'Završi',
    'End Date' => 'Datum završetka',
    'End Time' => 'Vreme završetka',
    'End date' => 'Datum završetka',
    'End time must be after start time!' => 'Vreme završetka mora biti nakon vremena početka!',
    'Extend deadline request' => 'Zahtev za produženje roka',
    'Filter' => 'Filter',
    'Filter tasks' => 'Filter zadataka',
    'Finish Task' => 'Završi zadatak',
    'General' => 'Opšte',
    'General Settings' => 'Opšte postavke',
    'Hide this list once all tasks are completed' => 'Sakrij ovu listu nakon završetka svih zadataka',
    'I\'m assigned' => 'Dodeljen sam',
    'I\'m responsible' => 'Ja sam odgovoran',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Ako nije odabran nijedan dodeljeni korisnik, svaki član prostora s dozvolom za obradu neraspoređenih zadataka može obraditi zadatak.',
    'In Progress' => 'U toku',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'U slučaju da je opcija pregleda aktivna, <strong>odgovorni korisnik</strong> moraće da pregleda i odbije ili potvrditi ovaj zadatak pre završetka.',
    'Invalid task list selection.' => 'Nevažeći odabir liste zadataka.',
    'Let Task Review' => 'Neka zadatak pregleda',
    'Manage tasks' => 'Upravljanje zadacima',
    'No pending tasks found' => 'Nisu pronađeni zadaci na čekanju',
    'No results found for the given filter.' => 'Nisu pronađeni rezultati za zadani filtar.',
    'Open Task' => 'Otvorite zadatak',
    'Other Tasks' => 'Ostali zadaci',
    'Overdue' => 'Probijen rok',
    'Overview' => 'Pregled',
    'Parent Task' => 'Roditelj zadatak',
    'Pending' => 'Na čekanju',
    'Process unassigned tasks' => 'Obradite neraspoređene zadatke',
    'Ready For Review' => 'Spremno za pregledanje',
    'Receive Notifications for Task Reminder.' => 'Primajte obaveštenja za podsetnik na zadatak.',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Primajte obavštenja o zadacima (ažuriranja rokova, promjene statusa ...).',
    'Reject Task' => 'Odbij zadatak',
    'Reminder' => 'Podsetnik',
    'Reminder sent' => 'Pošalji podsjetnik',
    'Reminders' => 'Podsetnik',
    'Request extension' => 'Zatraži produženje',
    'Request sent' => 'Zahtev poslat',
    'Reset Task' => 'Obnovi zadatak',
    'Review by responsible user required' => 'Potreban pregled od strane odgovornog korisnika',
    'Scheduling' => 'Zakazivanje',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Prikaži {count} više izvršenih {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'Redosled',
    'Sort order' => 'Sortiranje',
    'Spaces' => 'Prostori',
    'Start' => 'Početak',
    'Start Date' => 'Datum početka',
    'Start Time' => 'Vreme početka',
    'Start date' => 'Početni datum',
    'Status' => 'Status',
    'Task' => 'Zadatak',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Zadatak {task} u prostoru {spaceName} završava u {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Zadatak {task} u prostoru {spaceName} započinje u {dateTime}.',
    'Tasks' => 'Zadaci',
    'Tasks: Reminder' => 'Zadaci: Podsetnik',
    'This task can only be processed by assigned and responsible users.' => 'Ovaj zadatak mogu obraditi samo dodeljeni i odgovorni korisnici.',
    'This task requires to be reviewed by a responsible' => 'Ovaj zadatak mora biti pregledan od strane odgovornog',
    'Time Zone' => 'Vremenska zona',
    'Title' => 'Funkcija',
    'Title and Color' => 'Naslov i boja',
    'Today' => 'Danas',
    'Unsorted' => 'Nesortirano',
    'View Online' => 'Vidi Online',
    'You are assigned!' => 'Vi ste dodijeljeni!',
    'You are responsible!' => 'Vi ste odgovorni!',
    'You have insufficient permissions to perform that operation!' => 'Nemate ovlaštenje za sprovođenje ove operacije!',
    'Your Reminder for task {task}' => 'Vaš podsetnik za zadatak {task}',
    'view all' => 'vidi sve',
    '{displayName} is assigned to this task' => '{displayName} je dodat u ovaj zadatak',
    '{displayName} is responsible for this task' => '{displayName} je odgovoran/a za ovaj zadatak',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => 'Korisnik {userName} dodijelio vas je kao odgovornu osobu u zadatku {task} iz prostora {spaceName}.',
    '{userName} assigned you to task {task} in space {spaceName}.' => 'Korisnik {userName} dodelio vam je zadatak {task} u prostoru {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => 'Korisnik {userName} izvršio je zadatak {task} u prostoru {spaceName}.',
    '{userName} completed task {task}.' => '{userName} je završio/la zadatak {task}.',
    '{userName} finished task {task}.' => '{userName} završio je zadatak {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => 'Korisnik {userName} promenio je rok za zadatak {task} u prostoru {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} ponovno je pokrenuo zadatak {task} u prostoru {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => 'Korisnik {userName} odbacio je zadatak {task} u prostoru {spaceName} kao nepotpun.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => 'Korisnik {userName} označio je zadatak {task} u prostoru {spaceName} kao dovršen.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} zahteva produženje roka za zadatak {task} u prostoru {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} traži da pregledate zadatak {task} u prostoru {spaceName}.',
    '{userName} reset task {task}.' => '{userName} resetuje zadatak {task}.',
    '{userName} reviewed task {task}.' => '{userName} je pregledao/la zadatak {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => 'Korisnik {userName} započeo je rad na zadatku {task} u prostoru {spaceName}.',
    '{userName} works on task {task}.' => '{userName} radi na zadatku {task}.',
    '1 Day before' => '',
    '1 Month before' => '',
    '1 Week before' => '',
    '2 Days before' => '',
    '2 Weeks before' => '',
    '3 Weeks before' => '',
    '<strong>New</strong> Task' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Additional options' => '',
    'Any user with a "Process unassigned tasks" permission can work on this task' => '',
    'Assign myself' => '',
    'Assigned' => '',
    'Assigned users' => '',
    'At least 1 Hour before' => '',
    'At least 2 Hours before' => '',
    'Attachments' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Deadline at' => '',
    'Do not remind' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'If empty any user can complete the task.' => '',
    'In Review' => '',
    'Main Navigation' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'No Scheduling set for this Task' => '',
    'Pending Review' => '',
    'Remind Mode' => '',
    'Responsible' => '',
    'Responsible users' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Starting at' => '',
    'Task List' => '',
    'Task Users have been notified' => '',
    'Task content ID' => '',
    'Title of your task list' => '',
    'ending Review' => '',
    '{count,plural,=1{# day} other{# days}} remaining' => '',
];

==> tasks-v1.9.2.zip: tasks/messages/sr/base.php <==
<?php

return [
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Dodeljeni korisnici</strong> smeju raditi na ovom zadatku.',
    '<strong>Confirm</strong> task deletion' => '<strong>Potvrdi</strong> brisanje zadatka',
    '<strong>Create</strong> task list' => '<strong>Stvori</strong> listu zadataka',
    '<strong>Edit</strong> task' => '<strong>Uredi</strong> zadatak',
    '<strong>Edit</strong> task list' => '<strong>Uredi</strong> listu zadataka',
    '<strong>Task</strong> Overview' => '<strong>Zadatak</strong> Pregled',
    '<strong>Your</strong> tasks' => '<strong>Vaši</strong> zadaci',
    'Accept Task' => 'Prihvati zadatak',
    'Add Deadline to space calendar' => 'Dodajte rok u kalendar prostora',
    'Add checkpoint...' => 'Dodaj završnu tačku...',
    'Add reminder' => 'Dodaj podsetnik',
    'Add responsible users' => 'Dodajte odgovorne korisnike',
    'Add schedule to the space calendar' => 'Dodajte raspored u kalendar prostora',
    'Add task' => 'Dodaj zadatak',
    'Add to space calendar' => 'Dodaj u kalendar prostora',
    'All Day' => 'Celi dan',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Omogućuje korisniku kreiranje novih zadataka, korisnik će moći uređivati i brisati samo svoje zadatke',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Omogućuje korisniku stvaranje, brisanje i uređivanje zadataka i popisa te sortiranje zadataka i popisa',
    'Allows the user to process unassigned tasks' => 'Omogućuje korisniku obradu neraspoređenih zadataka',
    'Already requested' => 'Već zatraženo',
    'Assign users' => 'Dodeli korisnike',
    'Assignment' => 'Zadatak',
    'Begin Task' => 'Započnite zadatak',
    'Checklist Items' => 'Stavke ček liste',
    'Checklist:' => 'Lista za čekiranje:',
    'Close' => 'Zatvori',
    'Color' => 'Boja',
    'Completed' => 'Dovršeno',
    'Continue Review' => 'Nastavite s pregledom',
    'Create tasks' => 'Kreiraj zadataka',
    'Created by me' => 'Kreirao sam',
    'Date' => 'Datum',
    'Deadline: ' => 'Rok:',
    'Delete' => 'Obriši',
    'Delete list' => 'Izbriši listu',
    'Description' => 'Opis',
    'Do you really want to delete this task?' => 'Želite li stvarno izbrisati taj zadatak?',
    'Don\'t add to calendar' => 'Ne dodavaj u kalendar',
    'Edit' => 'Uredi',
    'Edit item (empty field will be removed)...' => 'Uredi stavku (prazno polje će biti uklonjeno) ...',
    'Edit list' => 'Uredi listu',
    'End' => 'Završi',
    'End Date' => 'Datum završetka',
    'End Time' => 'Vreme završetka',
    'End date' => 'Datum završetka',
    'End time must be after start time!' => 'Vreme završetka mora biti nakon vremena početka!',
    'Extend deadline request' => 'Zahtev za produženje roka',
    'Filter' => 'Filter',
    'Filter tasks' => 'Filter zadataka',
    'Finish Task' => 'Završi zadatak',
    'General' => 'Opšte',
    'General Settings' => 'Opšte postavke',
    'Hide this list once all tasks are completed' => 'Sakrij ovu listu nakon završetka svih zadataka',
    'I\'m assigned' => 'Dodeljen sam',
    'I\'m responsible' => 'Ja sam odgovoran',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Ako nije odabran nijedan dodeljeni korisnik, svaki član prostora s dozvolom za obradu neraspoređenih zadataka može obraditi zadatak.',
    'In Progress' => 'U toku',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'U slučaju da je opcija pregleda aktivna, <strong>odgovorni korisnik</strong> moraće da pregleda i odbije ili potvrditi ovaj zadatak pre završetka.',
    'Invalid task list selection.' => 'Nevažeći odabir liste zadataka.',
    'Let Task Review' => 'Neka zadatak pregleda',
    'Manage tasks' => 'Upravljanje zadacima',
    'No pending tasks found' => 'Nisu pronađeni zadaci na čekanju',
    'No results found for the given filter.' => 'Nisu pronađeni rezultati za zadani filtar.',
    'Open Task' => 'Otvorite zadatak',
    'Other Tasks' => 'Ostali zadaci',
    'Overdue' => 'Probijen rok',
    'Overview' => 'Pregled',
    'Parent Task' => 'Roditelj zadatak',
    'Pending' => 'Na čekanju',
    'Process unassigned tasks' => 'Obradite neraspoređene zadatke',
    'Ready For Review' => 'Spremno za pregledanje',
    'Receive Notifications for Task Reminder.' => 'Primajte obaveštenja za podsetnik na zadatak.',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Primajte obavštenja o zadacima (ažuriranja rokova, promjene statusa ...).',
    'Reject Task' => 'Odbij zadatak',
    'Reminder' => 'Podsetnik',
    'Reminder sent' => 'Pošalji podsjetnik',
    'Reminders' => 'Podsetnik',
    'Request extension' => 'Zatraži produženje',
    'Request sent' => 'Zahtev poslat',
    'Reset Task' => 'Obnovi zadatak',
    'Review by responsible user required' => 'Potreban pregled od strane odgovornog korisnika',
    'Scheduling' => 'Zakazivanje',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Prikaži {count} više izvršenih {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'Redosled',
    'Sort order' => 'Sortiranje',
    'Spaces' => 'Prostori',
    'Start' => 'Početak',
    'Start Date' => 'Datum početka',
    'Start Time' => 'Vreme početka',
    'Start date' => 'Početni datum',
    'Status' => 'Status',
    'Task' => 'Zadatak',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Zadatak {task} u prostoru {spaceName} završava u {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Zadatak {task} u prostoru {spaceName} započinje u {dateTime}.',
    'Tasks' => 'Zadaci',
    'Tasks: Reminder' => 'Zadaci: Podsetnik',
    'This task requires to be reviewed by a responsible' => 'Ovaj zadatak mora biti pregledan od strane odgovornog',
    'Time Zone' => 'Vremenska zona',
    'Title' => 'Funkcija',
    'Title and Color' => 'Naslov i boja',
    'Today' => 'Danas',
    'Unsorted' => 'Nesortirano',
    'View Online' => 'Vidi Online',
    'You have insufficient permissions to perform that operation!' => 'Nemate ovlaštenje za sprovođenje ove operacije!',
    'Your Reminder for task {task}' => 'Vaš podsetnik za zadatak {task}',
    'view all' => 'vidi sve',
    '{displayName} is assigned to this task' => '{displayName} je dodat u ovaj zadatak',
    '{displayName} is responsible for this task' => '{displayName} je odgovoran/a za ovaj zadatak',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => 'Korisnik {userName} dodijelio vas je kao odgovornu osobu u zadatku {task} iz prostora {spaceName}.',
    '{userName} assigned you to task {task} in space {spaceName}.' => 'Korisnik {userName} dodelio vam je zadatak {task} u prostoru {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => 'Korisnik {userName} izvršio je zadatak {task} u prostoru {spaceName}.',
    '{userName} completed task {task}.' => '{userName} je završio/la zadatak {task}.',
    '{userName} finished task {task}.' => '{userName} završio je zadatak {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => 'Korisnik {userName} promenio je rok za zadatak {task} u prostoru {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} ponovno je pokrenuo zadatak {task} u prostoru {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => 'Korisnik {userName} odbacio je zadatak {task} u prostoru {spaceName} kao nepotpun.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => 'Korisnik {userName} označio je zadatak {task} u prostoru {spaceName} kao dovršen.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} zahteva produženje roka za zadatak {task} u prostoru {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} traži da pregledate zadatak {task} u prostoru {spaceName}.',
    '{userName} reset task {task}.' => '{userName} resetuje zadatak {task}.',
    '{userName} reviewed task {task}.' => '{userName} je pregledao/la zadatak {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => 'Korisnik {userName} započeo je rad na zadatku {task} u prostoru {spaceName}.',
    '{userName} works on task {task}.' => '{userName} radi na zadatku {task}.',
    '1 Day before' => '',
    '1 Month before' => '',
    '1 Week before' => '',
    '2 Days before' => '',
    '2 Weeks before' => '',
    '3 Weeks before' => '',
    '<strong>New</strong> Task' => '',
    '<strong>Tasks</strong>' => '',
    '<strong>Tasks</strong> module configuration' => '',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => '',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => '',
    'Add entry to main navigation' => '',
    'Additional options' => '',
    'Assign myself' => '',
    'Assigned users' => '',
    'Assignments' => '',
    'At least 1 Hour before' => '',
    'At least 2 Hours before' => '',
    'Attachments' => '',
    'Checkpoints' => '',
    'Choose if you want the module to appear in the main navigation.' => '',
    'Completed lists' => '',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '',
    'Deadline' => '',
    'Do not remind' => '',
    'Filter by status' => '',
    'Filter by title' => '',
    'ID' => '',
    'If empty any user can complete the task.' => '',
    'In Review' => '',
    'Main Navigation' => '',
    'Maximum number of entries in widget' => '',
    'Module Widget' => '',
    'New list or search' => '',
    'No Scheduling set for this Task' => '',
    'Pending Review' => '',
    'Remind Mode' => '',
    'Request Review' => '',
    'Responsible' => '',
    'Responsible users' => '',
    'Show widget in Spaces' => '',
    'Show widget on Dashboard' => '',
    'Starting at' => '',
    'Task List' => '',
    'Task Users have been notified' => '',
    'Task content ID' => '',
    'Title of your task list' => '',
    '{count,plural,=1{# day} other{# days}} remaining' => '',
    '{displayName} is task creator' => '',
];
